const validateAs = (type) => ['', 'script', 'style', 'image', 'media', 'document', 'font'].indexOf(type) > -1;
const validateRel = (type) => ['preload', 'prefetch'].indexOf(type) > -1;
const domTokenListSupports = () => {
    try {
        return document.createElement('link').relList.supports('preload');
    }
    catch (e) {
        // link[rel=preload] is not supported
        console.warn('link[rel=preload] is not supported');
        return false;
    }
};
const VueLinkPre = {
    install: (Vue) => {
        let isSupported;
        const init = function () {
            isSupported = domTokenListSupports();
            if (!isSupported)
                console.info('Current browser does not support link[rel=preload] functionality');
        };
        Vue.addPreLink = function (elementHref, elementAs, elementRel) {
            if (!isSupported)
                return;
            if (elementAs === undefined)
                elementAs = 'script';
            if (!validateAs(elementAs))
                return;
            if (elementRel === undefined)
                elementRel = 'preload';
            if (!validateRel(elementRel))
                return;
            const lnk = document.createElement('link');
            const rel = document.createAttribute('rel');
            rel.value = elementRel;
            lnk.setAttributeNode(rel);
            const as = document.createAttribute('as');
            as.value = elementAs;
            lnk.setAttributeNode(as);
            const href = document.createAttribute('href');
            href.value = elementHref;
            lnk.setAttributeNode(href);
            document.head.appendChild(lnk);
        };
        Vue.preGroup = function (resourcesMap, elementRel) {
            for (const [key, value] of Object.entries(resourcesMap)) {
                if (validateAs(key) && value.length) {
                    value.forEach((item) => Vue.addPreLink(item, key, elementRel));
                }
            }
        };
        init();
    },
};

export default VueLinkPre;
//# sourceMappingURL=index.esm.js.map
